==> needle-0.2.0.tgz: package/test/needle_spec.js <==
var util = require('util'),
		EventEmitter = require('events').EventEmitter;
var needle = require('./../lib/needle');

var FakeRequest = function(args, callback){
	this.end = function(){ /* noop */ };
}

util.inherits(FakeRequest, EventEmitter);

describe('Needle', function(){
	
	var req;
	var spy = createSpy('mySpy');
	
	var disableRequests = function(){
		var http = require('http');
		spyOn(http, 'request').andReturn(new FakeRequest());		
		spyOn(this, 'setTimeout').andReturn(true); // dont wait for default timeout
	}
	
	describe('module', function(){
		
	  it('should expose version', function(){ 
			expect(needle.version).toBeDefined();
		});

		it('should export get/post/put/delete methods', function(){
			expect(Object.keys(needle)).toEqual(['version', 'get', 'post', 'put', 'delete']);
		})

	})

	describe('requests', function(){
		
		// common for all methods

		describe('by default', function(){

			it('should add http:// to request URL if missing', function(){
				disableRequests();
				var url = require('url');
				spyOn(url, 'parse').andCallThrough();
				needle.get('www.google.com');
				expect(url.parse).toHaveBeenCalledWith('http://www.google.com');
			})
			
			it('should not ask for a deflated response', function(){
				var req = needle.get('google.com');
				expect(req._headers['Accept-Encoding']).toBeUndefined();
			})

/* TODO
			it('should set a 10 sec timeout timer', function(){
				spyOn(this, 'setTimeout');
				needle.get('server.com/with/some/url')
				expect(setTimeout).toHaveBeenCalledWith(function(){}, 10000);
			})
*/
			it('should add Host, Connection, User-Agent and Accept headers', function(){
				var req = needle.get('some.com/url');
				expect(Object.keys(req._headers)).toEqual(['host', 'user-agent', 'connection', 'accept']);
			})
			
		})
		
		describe('when proxied', function(){
			
			beforeEach(function(){
				req = needle.post('finalhost.com/endpoint', {proxy: 'http://localhost:5141'});
			})
			
			it('should set Host header to final host', function(){
				expect(req._headers['host']).toEqual('finalhost.com');
			})
			
			it('should set the original (full) URL as the request path', function(){
				expect(req.path).toEqual('/endpoint');
			})
			
		})
		
		// common stuff for all requests
		
		
		describe('headers', function(){
			
			it('should accept setting custom headers', function(){
				var req = needle.get('random.url', {headers: {'X-Custom-Header': 'custom-value'}});
				expect(req._headers['x-custom-header']).toEqual('custom-value');
			})
			
			describe('HTTP basic auth', function(){
				
				it('should set an Authorization header when username & password are present', function(){

				})

				it('should not set Authorization header if only username or password are set', function(){

				})
				
				it('Authorization header should be Base64 encoded (& decodeable)', function(){
					
				})
				
			})

		})

		// specific for each method
		
		describe('GET', function(){
			
			it('should work', function(){
				
			})
			
			it('should not send any data')
			
		})
		
		describe('POST', function(){

			it('should require data', function(){
				
			})

			it('should work', function(){
				
			})
			
			it('should default to non-multipart', function(){
				
			})
			
			it('should add a Content-Length header', function(){
				
			})
			
			it('should send the data in ut8 encoding', function(){
				
			})
			
			describe('with multipart', function(){
				
				it('should also have a Content-Length header', function(){
					
				})
				
				it('should send the data in binary encoding', function(){
					
				})
				
			})
			
		})
		
		describe('PUT', function(){

			it('should work', function(){
				
			})

			it('should require data', function(){
				
			})

		})
		
		describe('DELETE', function(){

			it('should work', function(){
				
			})

		})
		
	})
	
	describe('errors', function(){
		

		describe('invalid URL', function(){
			

			describe('should not raise exceptions', function(){

			})

			describe('callback should include an error', function(){

			})

			describe('callback should not include a response', function(){

			})

			describe('callback should not include a body', function(){

			})
			
		})
		
		describe('non-existant host', function(){
			
			it('should not work', function(){
				
			})

			describe('should not raise exceptions', function(){

			})

			describe('callback should include an error', function(){

			})

			describe('callback should not include a response', function(){

			})

			describe('callback should not include a body', function(){

			})

		})
		
		describe('timeout', function(){
			
			it('should abort the request', function(){
				
			})
			
			describe('should not raise exceptions', function(){

			})

			describe('callback should include an error', function(){

			})

			describe('callback should not include a response', function(){

			})

			describe('callback should not include a body', function(){

			})			
		})
		
	})

});

==> needle-0.2.7.tgz: package/test/needle_spec.js <==
var util = require('util'),
		EventEmitter = require('events').EventEmitter;
var needle = require('./../lib/needle');

var FakeRequest = function(args, callback){
	this.end = function(){ /* noop */ };
	if(callback) callback();
}

util.inherits(FakeRequest, EventEmitter);

describe('Needle', function(){
	
	var req;
	var spy = createSpy('mySpy');
	
	var disableRequests = function(){
		var http = require('http');
		spyOn(http, 'request').andReturn(new FakeRequest());		
		spyOn(this, 'setTimeout').andReturn(true); // dont wait for default timeout
	}
	
	describe('module', function(){
		
	  it('should expose version', function(){ 
			expect(needle.version).toBeDefined();
		});

		it('should export head/get/post/put/delete methods', function(){
			expect(Object.keys(needle)).toEqual(['version', 'head', 'get', 'post', 'put', 'delete']);
		})

	})

	describe('requests', function(){
		
		// common for all methods

		describe('by default', function(){

			it('should add http:// to request URL if missing', function(){
				disableRequests();
				var url = require('url');
				spyOn(url, 'parse').andCallThrough();
				needle.get('www.google.com');
				expect(url.parse).toHaveBeenCalledWith('http://www.google.com');
			})
			
			it('should not ask for a deflated response', function(){
				spyOn(http, 'request').andCallThrough();
				needle.get('google.com');
				expect(http.request).not.toHaveBeenCalledWith({headers['Accept-Encoding']});
			})

/* TODO
			it('should set a 10 sec timeout timer', function(){
				spyOn(this, 'setTimeout');
				needle.get('server.com/with/some/url')
				expect(setTimeout).toHaveBeenCalledWith(function(){}, 10000);
			})
*/
			it('should add Host, Connection, User-Agent and Accept headers', function(){
				var req = needle.get('some.com/url');
				expect(Object.keys(req._headers)).toEqual(['host', 'user-agent', 'connection', 'accept']);
			})
			
		})
		
		describe('when proxied', function(){
			
			beforeEach(function(){
				req = needle.post('finalhost.com/endpoint', {proxy: 'http://localhost:5141'});
			})
			
			it('should set Host header to final host', function(){
				expect(req._headers['host']).toEqual('finalhost.com');
			})
			
			it('should set the original (full) URL as the request path', function(){
				expect(req.path).toEqual('/endpoint');
			})
			
		})
		
		// common stuff for all requests
		
		describe('headers', function(){
			
			it('should accept setting custom headers', function(){
				var req = needle.get('random.url', {headers: {'X-Custom-Header': 'custom-value'}});
				expect(req._headers['x-custom-header']).toEqual('custom-value');
			})
			
			describe('HTTP basic auth', function(){
				
				it('should set an Authorization header when username & password are present', function(){

				})

				it('should not set Authorization header if only username or password are set', function(){

				})
				
				it('Authorization header should be Base64 encoded (& decodeable)', function(){
					
				})
				
			})

		})

		// specific for each method
		
		describe('GET', function(){
			
			it('should work', function(){
				
			})
			
			it('should not send any data')
			
		})
		
		describe('POST', function(){

			it('should require data', function(){
				
			})

			it('should work', function(){
				
			})
			
			it('should default to non-multipart', function(){
				
			})
			
			it('should add a Content-Length header', function(){
				
			})
			
			it('should send the data in ut8 encoding', function(){
				
			})
			
			describe('with multipart', function(){
				
				it('should also have a Content-Length header', function(){
					
				})
				
				it('should send the data in binary encoding', function(){
					
				})
				
			})
			
		})
		
		describe('PUT', function(){

			it('should work', function(){
				
			})

			it('should require data', function(){
				
			})

		})
		
		describe('DELETE', function(){

			it('should work', function(){
				
			})

		})
		
	})
	
	describe('errors', function(){
		

		describe('invalid URL', function(){
			

			describe('should not raise exceptions', function(){

			})

			describe('callback should include an error', function(){

			})

			describe('callback should not include a response', function(){

			})

			describe('callback should not include a body', function(){

			})
			
		})
		
		describe('non-existant host', function(){
			
			it('should not work', function(){
				
			})

			describe('should not raise exceptions', function(){

			})

			describe('callback should include an error', function(){

			})

			describe('callback should not include a response', function(){

			})

			describe('callback should not include a body', function(){

			})

		})
		
		describe('timeout', function(){
			
			it('should abort the request', function(){
				
			})
			
			describe('should not raise exceptions', function(){

			})

			describe('callback should include an error', function(){

			})

			describe('callback should not include a response', function(){

			})

			describe('callback should not include a body', function(){

			})			
		})
		
	})

});
